@@ -138,7 +138,8 @@ beam <- function(X, type = "conditional", return.only = c("cor", "BF", "prob"),
 	           "return.only" = return.only,
 	           "time" = time1[3],
 	           "TinvStdev" = res$TinvStdev[,1],
-	           "s" = as.vector(res$s))
+	           "s" = as.vector(res$s),
+	           "rzij" = as.vector(res$rzij))
 
 	return(out)
 
